JSONListEdit in Django.
-----------------------

I've never written a django widget or field type, or anything custom like that
before, so I'm pretty much working this out as I go.

This is the django component to get my JSONListEdit JS/HTML widget thing into
django (forms/admin). https://github.com/danthedeckie/json_listedit_widget

I suspect this component will never be 'drop into django and it works!' as there
are too many variables you need to configure to get anything useful.

However, there is / will be a more useable-out-of-the-box component
(https://github.com/danthedeckie/django_jsonlisttable) which is based on this.
